## Menu-based wordlist generator:

#### Features include:
- Moodular and expandable project structure
- Manipulate your own or download from a list of predefined wordlists
- Easily generate via `crunch` charsets or masks
- Concatenate and intermix various wordlists
- Intellegent pre-run size calculations

![Some Commands Show-down](https://i.imgur.com/o6XCY7p.png)

## Usage:
### Setup:
    git clone https://github.com/codeswhite/stargen
    pip install interutils

### Run:
    cd stargen
    python3 run.py

---
